Extract posterior draws (or summaries) for the cell-level reporting
completeness rho returned from Stan as a generated quantity (rho_rep).
Usage
posterior_reporting(x, draws = FALSE, probs = c(0.1, 0.5, 0.9), ...)Extract posterior draws (or summaries) for the cell-level reporting
completeness rho returned from Stan as a generated quantity (rho_rep).
posterior_reporting(x, draws = FALSE, probs = c(0.1, 0.5, 0.9), ...)