Extract posterior summaries of the conflict effect by region. This is most
useful when you fit a model with partial pooling of conflict effects (random
slopes by region), by setting conflict = "region" in vrc_mortality() and/or
vrc_reporting().
The underlying Stan model always defines region-specific conflict effects
(beta_conf_rg for mortality and gamma_conf_rg for reporting). When the
corresponding feature is disabled (conflict = "fixed"), these region-specific
effects are equal to the global effect for all regions.